defmodule FrenzyWeb.FeedController do
  use FrenzyWeb, :controller
  alias Frenzy.{Repo, Group, Feed, Filter, Item}
  alias FrenzyWeb.Router.Helpers, as: Routes
  alias FrenzyWeb.Endpoint
  import Ecto.Query

  def show(conn, %{"id" => id}) do
    feed = Repo.get(Feed, id) |> Repo.preload(:filter)
    items = Repo.all(from Item, where: [feed_id: ^id, tombstone: false], order_by: [desc: :date])

    render(conn, "show.html", %{
      feed: feed,
      items: items
    })
  end

  def create(conn, %{"feed" => %{"group_id" => group_id, "feed_url" => feed_url}}) do
    group = Repo.get(Group, group_id)

    changeset =
      Ecto.build_assoc(group, :feeds, %{
        feed_url: feed_url,
        filter: %Filter{
          mode: "reject",
          score: 0
        }
      })

    {:ok, feed} = Repo.insert(changeset)

    redirect(conn, to: Routes.group_path(Endpoint, :show, group_id))
  end

  def delete(conn, %{"id" => id}) do
    feed = Repo.get(Feed, id)
    {:ok, _} = Repo.delete(feed)
    redirect(conn, to: Routes.group_path(Endpoint, :show, feed.group_id))
  end

  def enable_filter(conn, %{"id" => id}) do
    feed = Repo.get(Feed, id) |> Repo.preload(:filter)
    changeset = Feed.changeset(feed, %{filter_enabled: true})
    Repo.update(changeset)
    redirect(conn, to: Routes.feed_path(Endpoint, :show, id))
  end

  def disable_filter(conn, %{"id" => id}) do
    feed = Repo.get(Feed, id) |> Repo.preload(:filter)
    changeset = Feed.changeset(feed, %{filter_enabled: false})
    Repo.update(changeset)
    redirect(conn, to: Routes.feed_path(Endpoint, :show, id))
  end

  def refresh(conn, %{"id" => id}) do
    feed = Repo.get(Feed, id) |> Repo.preload(:filter)
    feed = Frenzy.UpdateFeeds.refresh(Frenzy.UpdateFeeds, feed)
    redirect(conn, to: Routes.feed_path(Endpoint, :show, feed.id))
  end
end
