defmodule FrenzyWeb.Router do
  use FrenzyWeb, :router

  pipeline :browser do
    plug :accepts, ["html"]
    plug :fetch_session
    plug :fetch_flash
    plug :protect_from_forgery
    plug :put_secure_browser_headers
    plug BasicAuth, use_config: {:frenzy, :auth}
  end

  pipeline :api do
    plug :accepts, ["json"]
  end

  scope "/", FrenzyWeb do
    pipe_through :browser

    get "/", GroupController, :index
    resources "/groups", GroupController, except: [:edit, :update]

    resources "/feeds", FeedController, only: [:show, :create, :delete]
    post "/feeds/:id/refresh", FeedController, :refresh
    post "/feeds/:id/enable_filter", FeedController, :enable_filter
    post "/feeds/:id/disable_filter", FeedController, :disable_filter

    resources "/filters", FilterController, only: [:edit, :update]
    post "/filters/:id/add_rule", FilterController, :add_rule
    post "/filters/:id/remove_rule", FilterController, :remove_rule

    resources "/items", ItemController, only: [:show]
    post "/items/:id/read", ItemController, :read
    post "/items/:id/unread", ItemController, :unread
  end

  scope "/", FrenzyWeb do
    pipe_through :api

    get "/fever", FeverController, :get
    get "/api/fever.php", FeverController, :get
    post "/fever", FeverController, :post
    post "/api/fever.php", FeverController, :post
  end

  # Other scopes may use custom stacks.
  # scope "/api", FrenzyWeb do
  #   pipe_through :api
  # end
end
